RepoQueryAnnotation class
Marks a repository method as a read/query and forces provider generation.
Use this when a method name matches a mutation prefix (for example
deleteBook) but is still a query.
Constructors
- RepoQueryAnnotation({bool? keepAlive})
-
Creates a query annotation, optionally overriding
keepAlive.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepAlive → bool?
-
Overrides RiverpodRepoAnnotation.keepAlive for this method only.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited