RiverpodRepoAnnotation class

Marks a repository interface for provider generation.

keepAlive applies to every generated query provider unless overridden with RepoQueryAnnotation.

Constructors

RiverpodRepoAnnotation({bool keepAlive = false})
Creates a repository annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keepAlive bool
When true, generated providers are kept alive instead of auto-disposed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited